import * as i0 from '@angular/core';
import { EventEmitter, Component, ViewEncapsulation, HostBinding, ViewChild, Input, Output, Pipe, inject, Optional, NgModule } from '@angular/core';
import { isString } from '@tethys/cdk';
import Cropper from 'cropperjs';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2$1 from 'ngx-tethys/loading';
import { ThyLoadingModule } from 'ngx-tethys/loading';
import { ThyNotifyService, ThyNotifyModule } from 'ngx-tethys/notify';
import { finalize } from 'rxjs/operators';
import * as i1 from 'ngx-tethys/dialog';
import { ThyDialogModule } from 'ngx-tethys/dialog';
import * as i3 from 'ngx-tethys/upload';
import { ThyUploadModule } from 'ngx-tethys/upload';
import * as i4 from 'ngx-tethys/button';
import { ThyButtonModule } from 'ngx-tethys/button';
import { isString as isString$1 } from '@tethys/cdk/is';

class ThyImageCropperComponent {
    /**
     * 图片资源
     */
    set imageSource(value) {
        if (!isString(value)) {
            this.imageFile = value;
            this.setImageSrc();
        }
        else {
            this.imageSrc = value;
        }
    }
    constructor() {
        this.cropperClass = true;
        /**
         * 图片加载的错误提示
         * @default 图片加载错误
         */
        this.thyImageErrorMessage = '图片加载错误';
        /**
         * 设置裁剪形状
         */
        this.thyCropperShape = 'rect';
        /**
         * 图片裁剪的数据更改(blob)
         * @default EventEmitter<thyCropDataChangeEvent>
         */
        this.thyCropDataChanged = new EventEmitter();
        /**
         * 图片加载完毕事件
         * @default EventEmitter<boolean>
         */
        this.thyImageReady = new EventEmitter();
        this.loadingDone = false;
        this.loadError = false;
        this.defaultCropperOptions = {
            viewMode: 2,
            aspectRatio: 1,
            movable: false,
            scalable: false,
            dragMode: 'move',
            cropBoxResizable: false,
            zoomable: true,
            guides: false,
            autoCrop: false,
            zoomOnWheel: true,
            checkCrossOrigin: true,
            preview: '.preview-image-warp',
            ready: (event) => {
                this.loadingDone = true;
                this.cropper.crop();
                return;
            }
        };
        this.crop = () => {
            const cropper = this.cropper;
            const canvas = cropper.getCroppedCanvas();
            const promise = new Promise((resolve) => {
                canvas.toBlob((blob) => resolve({ blob }));
            });
            promise.then((res) => {
                return this.thyCropDataChanged.emit(res);
            });
        };
    }
    ngOnInit() { }
    onLoad(event) {
        var _a;
        this.loadError = false;
        const image = event.target;
        image.addEventListener('ready', () => {
            this.thyImageReady.emit(true);
        });
        const { viewMode, aspectRatio } = this.defaultCropperOptions;
        const customCropperOptions = {
            viewMode: this.thyCropperViewMode || this.thyCropperViewMode === 0 ? this.thyCropperViewMode : viewMode,
            aspectRatio: this.thyCropperAspectRatio ? this.thyCropperAspectRatio : aspectRatio
        };
        this.cropperOptions = Object.assign(Object.assign(Object.assign({}, this.defaultCropperOptions), { crop: (event) => {
                this.crop();
            } }), customCropperOptions);
        if ((_a = this.cropperOptions) === null || _a === void 0 ? void 0 : _a.checkCrossOrigin) {
            image.crossOrigin = 'anonymous';
        }
        if (this.cropper) {
            this.cropper.destroy();
            this.cropper = undefined;
        }
        this.cropper = new Cropper(image, this.cropperOptions);
    }
    onError(event) {
        this.loadError = true;
        this.loadingDone = true;
    }
    setImageSrc() {
        const reader = new FileReader();
        reader.onloadend = () => {
            const cropperRef = this.cropper;
            if (cropperRef) {
                cropperRef.destroy();
                cropperRef.replace(reader.result.toString(), true);
                cropperRef.reset();
            }
            this.imageSrc = reader.result.toString();
        };
        if (this.imageFile) {
            reader.readAsDataURL(this.imageFile);
        }
        else {
            this.imageSrc = '';
        }
    }
}
ThyImageCropperComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ThyImageCropperComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.2", type: ThyImageCropperComponent, selector: "thy-image-cropper", inputs: { imageSource: ["thyImage", "imageSource"], thyImageErrorMessage: "thyImageErrorMessage", thyCropperViewMode: "thyCropperViewMode", thyCropperAspectRatio: "thyCropperAspectRatio", thyCropperShape: "thyCropperShape" }, outputs: { thyCropDataChanged: "thyCropDataChanged", thyImageReady: "thyImageReady" }, host: { properties: { "class.thy-image-cropper-round": "thyCropperShape === \"round\"", "class.thy-image-cropper": "this.cropperClass" } }, viewQueries: [{ propertyName: "image", first: true, predicate: ["image"], descendants: true, static: true }], ngImport: i0, template: "<thy-loading [thyDone]=\"loadingDone\"></thy-loading>\n\n<div class=\"alert alert-warning\" *ngIf=\"loadError\">{{ thyImageErrorMessage }}</div>\n\n<div class=\"cropper-content\" [class.image-ready]=\"loadingDone\">\n  <img #image alt=\"image\" [src]=\"imageSrc\" (load)=\"onLoad($event)\" (error)=\"onError($event)\" />\n</div>\n", dependencies: [{ kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i2$1.ThyLoadingComponent, selector: "thy-loading", inputs: ["thyDone", "thyTip", "thyIsMask"] }], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperComponent, decorators: [{
            type: Component,
            args: [{ selector: 'thy-image-cropper', encapsulation: ViewEncapsulation.None, host: {
                        '[class.thy-image-cropper-round]': 'thyCropperShape === "round"'
                    }, template: "<thy-loading [thyDone]=\"loadingDone\"></thy-loading>\n\n<div class=\"alert alert-warning\" *ngIf=\"loadError\">{{ thyImageErrorMessage }}</div>\n\n<div class=\"cropper-content\" [class.image-ready]=\"loadingDone\">\n  <img #image alt=\"image\" [src]=\"imageSrc\" (load)=\"onLoad($event)\" (error)=\"onError($event)\" />\n</div>\n" }]
        }], ctorParameters: function () { return []; }, propDecorators: { cropperClass: [{
                type: HostBinding,
                args: ['class.thy-image-cropper']
            }], image: [{
                type: ViewChild,
                args: ['image', { static: true }]
            }], imageSource: [{
                type: Input,
                args: ['thyImage']
            }], thyImageErrorMessage: [{
                type: Input
            }], thyCropperViewMode: [{
                type: Input
            }], thyCropperAspectRatio: [{
                type: Input
            }], thyCropperShape: [{
                type: Input
            }], thyCropDataChanged: [{
                type: Output
            }], thyImageReady: [{
                type: Output
            }] } });

class ThyCropperSizeTextPipe {
    transform(size, previewSizes) {
        if (size || previewSizes) {
            const currentSize = previewSizes ? previewSizes[0] : size;
            const width = parseFloat(currentSize.width);
            const height = parseFloat(currentSize.height);
            return width + 'X' + height;
        }
        else {
            return '';
        }
    }
}
ThyCropperSizeTextPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyCropperSizeTextPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
ThyCropperSizeTextPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.2", ngImport: i0, type: ThyCropperSizeTextPipe, name: "thyCropperSizeText" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyCropperSizeTextPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'thyCropperSizeText'
                }]
        }] });
class ThyCropperSizeStylePipe {
    transform(size) {
        if (size) {
            const { width, height } = size;
            if (width && height) {
                const stringWidth = isString$1(width) ? width : `${width}px`;
                const stringHeight = isString$1(height) ? height : `${height}px`;
                return { width: `${stringWidth}`, height: `${stringHeight}` };
            }
            else {
                return { width: '100%', height: '100%' };
            }
        }
        else {
            return { width: '100%', height: '100%' };
        }
    }
}
ThyCropperSizeStylePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyCropperSizeStylePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
ThyCropperSizeStylePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.2", ngImport: i0, type: ThyCropperSizeStylePipe, name: "thyCropperSizeStyle" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyCropperSizeStylePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'thyCropperSizeStyle'
                }]
        }] });

class ThyImageCropperDialogComponent {
    constructor(dialog, dialogContainer, ngZone) {
        this.dialog = dialog;
        this.dialogContainer = dialogContainer;
        this.ngZone = ngZone;
        /**
         * 标题
         * @default 图片
         */
        this.title = '图片';
        /**
         * 默认预览大小
         * @default { width: '120px', height: '120px' }
         */
        this.size = { width: '120px', height: '120px' };
        /**
         * 图片资源
         */
        this.uploadTips = '(最佳尺寸 120X120 像素，可以上传高质量图片进行裁剪)';
        /**
         * 设置裁剪形状
         */
        this.cropperShape = 'rect';
        /**
         * 确定事件
         */
        this.thyConfirm = new EventEmitter();
        this.saving = false;
        this.notifyService = inject(ThyNotifyService);
    }
    ngOnInit() { }
    selectImage(image) {
        if (image.files.length > 0) {
            this.image = image.files[0];
        }
    }
    save() {
        const cropper = this.cropperRef.cropper;
        if (cropper) {
            this.saving = true;
            cropper.getCroppedCanvas().toBlob((blob) => {
                const file = new File([blob], 'avatar.png', { type: 'image/jpeg' });
                if (this.confirmAction) {
                    this.confirmAction(file)
                        .pipe(finalize(() => {
                        this.saving = false;
                    }))
                        .subscribe(() => {
                        this.close();
                    }, (error) => {
                        this.notifyService.error(error);
                    });
                }
                else {
                    this.thyConfirm.emit(file);
                    this.saving = false;
                }
            });
        }
        else {
            this.thyConfirm.emit();
        }
    }
    close() {
        if (this.dialogContainer) {
            this.ngZone.run(() => {
                this.dialog.close();
            });
        }
    }
}
ThyImageCropperDialogComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperDialogComponent, deps: [{ token: i1.ThyDialog }, { token: i1.ThyDialogContainerComponent, optional: true }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
ThyImageCropperDialogComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.2", type: ThyImageCropperDialogComponent, selector: "thy-image-cropper-dialog", inputs: { title: ["thyTitle", "title"], size: ["thySize", "size"], previewSizes: ["thyPreviewSizes", "previewSizes"], image: ["thyImage", "image"], uploadTips: ["thyUploadTips", "uploadTips"], cropperViewMode: ["thyCropperViewMode", "cropperViewMode"], cropperAspectRatio: ["thyCropperAspectRatio", "cropperAspectRatio"], cropperShape: ["thyCropperShape", "cropperShape"], confirmAction: ["thyConfirmAction", "confirmAction"] }, outputs: { thyConfirm: "thyConfirm" }, host: { properties: { "class.thy-image-cropper-dialog-round": "cropperShape === \"round\"" }, classAttribute: "thy-dialog-content thy-image-cropper-dialog" }, viewQueries: [{ propertyName: "cropperRef", first: true, predicate: ["cropper"], descendants: true, static: true }], ngImport: i0, template: "<thy-dialog-header [thyTitle]=\"'\u4E0A\u4F20' + title\"></thy-dialog-header>\n<thy-dialog-body class=\"cropper-dialog-body\">\n  <div class=\"cropper-content-container\">\n    <thy-image-cropper\n      #cropper\n      [thyImage]=\"image\"\n      [thyCropperAspectRatio]=\"cropperAspectRatio\"\n      [thyCropperViewMode]=\"cropperViewMode\"\n      [thyCropperShape]=\"cropperShape\"\n    ></thy-image-cropper>\n    <div class=\"avatar-text-desc\">\n      <thy-file-select thyStopPropagation (thyOnFileSelect)=\"selectImage($event)\" thyAcceptType=\".jpg,.png,.jpeg\">\n        <button class=\"pl-0\" thyButton=\"link\">\u91CD\u65B0\u4E0A\u4F20</button>\n      </thy-file-select>\n      <span class=\"text-desc\">{{ uploadTips }}</span>\n    </div>\n  </div>\n  <div class=\"preview-container\">\n    \u9884\u89C8\n    <div class=\"text-center\">\n      <ng-container *ngIf=\"previewSizes && previewSizes?.length; else defaultPreview\">\n        <ng-container *ngFor=\"let currentSize of previewSizes\">\n          <ng-template [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: currentSize }\"></ng-template>\n        </ng-container>\n      </ng-container>\n      <ng-template #defaultPreview>\n        <ng-template [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: size }\"></ng-template>\n      </ng-template>\n    </div>\n  </div>\n  <ng-template #preview let-size>\n    <div class=\"preview-image-warp\" [ngStyle]=\"size | thyCropperSizeStyle\"></div>\n    <div class=\"preview-image-size\">{{ size | thyCropperSizeText }}</div>\n  </ng-template>\n</thy-dialog-body>\n\n<thy-dialog-footer thyShowBorderTop=\"true\" [thyAlign]=\"'right'\">\n  <button class=\"cancel\" thyButton=\"link-secondary\" (click)=\"close()\">\u53D6\u6D88</button>\n  <button thyButton=\"primary\" [thyLoading]=\"saving\" thyLoadingText=\"\u4E0A\u4F20\u4E2D\" (click)=\"save()\">\u786E\u5B9A</button>\n</thy-dialog-footer>\n", dependencies: [{ kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i3.ThyFileSelectComponent, selector: "[thyFileSelect],thy-file-select", inputs: ["thyMultiple", "thyAcceptFolder", "thyAcceptType", "thySizeThreshold"], outputs: ["thyOnFileSelect"] }, { kind: "component", type: i4.ThyButtonComponent, selector: "thy-button,[thy-button],[thyButton]", inputs: ["thyButton", "thyType", "thyLoading", "thyLoadingText", "thySize", "thyIcon", "thyBlock"] }, { kind: "component", type: i1.DialogHeaderComponent, selector: "thy-dialog-header", inputs: ["thyTitle", "thySize", "thyDivided", "thyTitleTranslationKey", "thyIcon"], outputs: ["thyOnClose"], exportAs: ["thyDialogHeader"] }, { kind: "component", type: i1.DialogBodyComponent, selector: "thy-dialog-body", inputs: ["thyClearPadding"], exportAs: ["thyDialogBody"] }, { kind: "component", type: i1.DialogFooterComponent, selector: "thy-dialog-footer", inputs: ["thyDivided", "thyAlign"], exportAs: ["thyDialogFooter"] }, { kind: "component", type: ThyImageCropperComponent, selector: "thy-image-cropper", inputs: ["thyImage", "thyImageErrorMessage", "thyCropperViewMode", "thyCropperAspectRatio", "thyCropperShape"], outputs: ["thyCropDataChanged", "thyImageReady"] }, { kind: "pipe", type: ThyCropperSizeTextPipe, name: "thyCropperSizeText" }, { kind: "pipe", type: ThyCropperSizeStylePipe, name: "thyCropperSizeStyle" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperDialogComponent, decorators: [{
            type: Component,
            args: [{ selector: 'thy-image-cropper-dialog', host: {
                        class: 'thy-dialog-content thy-image-cropper-dialog',
                        '[class.thy-image-cropper-dialog-round]': 'cropperShape === "round"'
                    }, template: "<thy-dialog-header [thyTitle]=\"'\u4E0A\u4F20' + title\"></thy-dialog-header>\n<thy-dialog-body class=\"cropper-dialog-body\">\n  <div class=\"cropper-content-container\">\n    <thy-image-cropper\n      #cropper\n      [thyImage]=\"image\"\n      [thyCropperAspectRatio]=\"cropperAspectRatio\"\n      [thyCropperViewMode]=\"cropperViewMode\"\n      [thyCropperShape]=\"cropperShape\"\n    ></thy-image-cropper>\n    <div class=\"avatar-text-desc\">\n      <thy-file-select thyStopPropagation (thyOnFileSelect)=\"selectImage($event)\" thyAcceptType=\".jpg,.png,.jpeg\">\n        <button class=\"pl-0\" thyButton=\"link\">\u91CD\u65B0\u4E0A\u4F20</button>\n      </thy-file-select>\n      <span class=\"text-desc\">{{ uploadTips }}</span>\n    </div>\n  </div>\n  <div class=\"preview-container\">\n    \u9884\u89C8\n    <div class=\"text-center\">\n      <ng-container *ngIf=\"previewSizes && previewSizes?.length; else defaultPreview\">\n        <ng-container *ngFor=\"let currentSize of previewSizes\">\n          <ng-template [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: currentSize }\"></ng-template>\n        </ng-container>\n      </ng-container>\n      <ng-template #defaultPreview>\n        <ng-template [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: size }\"></ng-template>\n      </ng-template>\n    </div>\n  </div>\n  <ng-template #preview let-size>\n    <div class=\"preview-image-warp\" [ngStyle]=\"size | thyCropperSizeStyle\"></div>\n    <div class=\"preview-image-size\">{{ size | thyCropperSizeText }}</div>\n  </ng-template>\n</thy-dialog-body>\n\n<thy-dialog-footer thyShowBorderTop=\"true\" [thyAlign]=\"'right'\">\n  <button class=\"cancel\" thyButton=\"link-secondary\" (click)=\"close()\">\u53D6\u6D88</button>\n  <button thyButton=\"primary\" [thyLoading]=\"saving\" thyLoadingText=\"\u4E0A\u4F20\u4E2D\" (click)=\"save()\">\u786E\u5B9A</button>\n</thy-dialog-footer>\n" }]
        }], ctorParameters: function () {
        return [{ type: i1.ThyDialog }, { type: i1.ThyDialogContainerComponent, decorators: [{
                        type: Optional
                    }] }, { type: i0.NgZone }];
    }, propDecorators: { title: [{
                type: Input,
                args: ['thyTitle']
            }], size: [{
                type: Input,
                args: ['thySize']
            }], previewSizes: [{
                type: Input,
                args: ['thyPreviewSizes']
            }], image: [{
                type: Input,
                args: ['thyImage']
            }], uploadTips: [{
                type: Input,
                args: ['thyUploadTips']
            }], cropperViewMode: [{
                type: Input,
                args: ['thyCropperViewMode']
            }], cropperAspectRatio: [{
                type: Input,
                args: ['thyCropperAspectRatio']
            }], cropperShape: [{
                type: Input,
                args: ['thyCropperShape']
            }], confirmAction: [{
                type: Input,
                args: ['thyConfirmAction']
            }], thyConfirm: [{
                type: Output
            }], cropperRef: [{
                type: ViewChild,
                args: ['cropper', { static: true }]
            }] } });

class ThyImageCropperModule {
}
ThyImageCropperModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ThyImageCropperModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperModule, declarations: [ThyImageCropperComponent, ThyImageCropperDialogComponent, ThyCropperSizeTextPipe, ThyCropperSizeStylePipe], imports: [CommonModule, ThyLoadingModule, ThyUploadModule, ThyButtonModule, ThyDialogModule, ThyNotifyModule], exports: [ThyImageCropperComponent, ThyImageCropperDialogComponent] });
ThyImageCropperModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperModule, imports: [CommonModule, ThyLoadingModule, ThyUploadModule, ThyButtonModule, ThyDialogModule, ThyNotifyModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyImageCropperModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ThyImageCropperComponent, ThyImageCropperDialogComponent, ThyCropperSizeTextPipe, ThyCropperSizeStylePipe],
                    imports: [CommonModule, ThyLoadingModule, ThyUploadModule, ThyButtonModule, ThyDialogModule, ThyNotifyModule],
                    exports: [ThyImageCropperComponent, ThyImageCropperDialogComponent],
                    providers: []
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ThyImageCropperComponent, ThyImageCropperDialogComponent, ThyImageCropperModule };
//# sourceMappingURL=tethys-pro-image-cropper.mjs.map
