import * as i0 from '@angular/core';
import { Directive, Component, HostBinding, ViewChild, Input, NgModule } from '@angular/core';
import { isString } from '@tethys/cdk';
import * as i1 from '@angular/platform-browser';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';

/**
 * @internal
 */
class ThyMediaPlayerBaseComponent {
    set fileSrc(value) {
        if (isString(value)) {
            this.internalFileSrc = this.sanitizer.bypassSecurityTrustResourceUrl(value);
        }
        else {
            this.internalFileSrc = value;
        }
    }
    get fileSrc() {
        return this.internalFileSrc;
    }
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.showErrorTip = false;
        this.showMedia = true;
        this.errorTipText = '';
        this.internalFileSrc = '';
    }
    ngOnInit() { }
    onLoadedmetadata(event) { }
    onCanPlay() {
        this.showErrorTip = false;
    }
    onError(event) {
        var _a;
        const errorCode = (_a = event.target.error) === null || _a === void 0 ? void 0 : _a.code;
        if (errorCode === 3 || errorCode === 4) {
            this.errorTipText = this.errorTips['formatError'];
        }
        else {
            this.errorTipText = this.errorTips['networkError'];
        }
        setTimeout(() => {
            this.showErrorTip = true;
        }, 1000);
    }
}
ThyMediaPlayerBaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyMediaPlayerBaseComponent, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Directive });
ThyMediaPlayerBaseComponent.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.2.2", type: ThyMediaPlayerBaseComponent, selector: "[thyMediaPlayerBase]", ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyMediaPlayerBaseComponent, decorators: [{
            type: Directive,
            args: [{ selector: '[thyMediaPlayerBase]' }]
        }], ctorParameters: function () { return [{ type: i1.DomSanitizer }]; } });

class ThyAudioPlayerComponent extends ThyMediaPlayerBaseComponent {
    /**
     * 媒体资源的url
     */
    set thySrc(src) {
        this.fileSrc = src;
    }
    constructor(sanitizer) {
        super(sanitizer);
        this.sanitizer = sanitizer;
        this.audioPlayerClass = true;
        /**
         * 当下载到足够播放的媒体文件，是否可以自动播放
         */
        this.thyAutoPlay = false;
        this.errorTips = {
            formatError: '该音频暂不支持预览，请升级浏览器版本或下载查看',
            networkError: '当前网络异常，请刷新后重试'
        };
    }
    onLoadedmetadata(event) {
        var _a, _b;
        const duration = (_b = (_a = this.audio) === null || _a === void 0 ? void 0 : _a.nativeElement) === null || _b === void 0 ? void 0 : _b.duration;
        if (!(duration && duration > 0)) {
            this.showErrorTip = true;
        }
    }
}
ThyAudioPlayerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyAudioPlayerComponent, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component });
ThyAudioPlayerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.2", type: ThyAudioPlayerComponent, selector: "thy-audio-player", inputs: { thySrc: "thySrc", thyAutoPlay: "thyAutoPlay" }, host: { properties: { "class.thy-audio-player": "this.audioPlayerClass" } }, viewQueries: [{ propertyName: "audio", first: true, predicate: ["audio"], descendants: true }], usesInheritance: true, ngImport: i0, template: `
        <div class="audio-content">
            <audio
                #audio
                class="audio"
                [src]="fileSrc"
                [muted]="false"
                [autoplay]="thyAutoPlay"
                [controls]="true"
                (loadedmetadata)="onLoadedmetadata($event)"
                (error)="onError($event)"
                (canplay)="onCanPlay()"
                *ngIf="showMedia"
            ></audio>
            <div class="error-tip" *ngIf="showErrorTip">
                {{ errorTipText }}
            </div>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyAudioPlayerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'thy-audio-player',
                    template: `
        <div class="audio-content">
            <audio
                #audio
                class="audio"
                [src]="fileSrc"
                [muted]="false"
                [autoplay]="thyAutoPlay"
                [controls]="true"
                (loadedmetadata)="onLoadedmetadata($event)"
                (error)="onError($event)"
                (canplay)="onCanPlay()"
                *ngIf="showMedia"
            ></audio>
            <div class="error-tip" *ngIf="showErrorTip">
                {{ errorTipText }}
            </div>
        </div>
    `
                }]
        }], ctorParameters: function () { return [{ type: i1.DomSanitizer }]; }, propDecorators: { audioPlayerClass: [{
                type: HostBinding,
                args: ['class.thy-audio-player']
            }], audio: [{
                type: ViewChild,
                args: ['audio']
            }], thySrc: [{
                type: Input
            }], thyAutoPlay: [{
                type: Input
            }] } });

class ThyVideoPlayerComponent extends ThyMediaPlayerBaseComponent {
    /**
     * 媒体资源的url
     */
    set thySrc(src) {
        this.fileSrc = src;
    }
    constructor(sanitizer) {
        super(sanitizer);
        this.sanitizer = sanitizer;
        this.class = 'thy-video-player thy-media-player';
        /**
         * 当下载到足够播放的媒体文件，是否可以自动播放
         */
        this.thyAutoPlay = false;
        this.errorTips = {
            formatError: '该视频暂不支持预览，请升级浏览器版本或下载查看',
            networkError: '当前网络异常，请刷新后重试'
        };
    }
    ngOnInit() { }
    onLoadedmetadata(event) { }
}
ThyVideoPlayerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyVideoPlayerComponent, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component });
ThyVideoPlayerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.2", type: ThyVideoPlayerComponent, selector: "thy-video-player", inputs: { thySrc: "thySrc", thyAutoPlay: "thyAutoPlay" }, host: { properties: { "class": "this.class" } }, viewQueries: [{ propertyName: "video", first: true, predicate: ["video"], descendants: true }], usesInheritance: true, ngImport: i0, template: `
        <video
            #video
            class="media-content"
            [src]="fileSrc"
            [muted]="false"
            [autoplay]="thyAutoPlay"
            [controls]="true"
            (loadedmetadata)="onLoadedmetadata($event)"
            (error)="onError($event)"
            (canplay)="onCanPlay()"
            *ngIf="showMedia"
        ></video>
        <div class="error-tip" *ngIf="showErrorTip">
            {{ errorTipText }}
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyVideoPlayerComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'thy-video-player',
                    template: `
        <video
            #video
            class="media-content"
            [src]="fileSrc"
            [muted]="false"
            [autoplay]="thyAutoPlay"
            [controls]="true"
            (loadedmetadata)="onLoadedmetadata($event)"
            (error)="onError($event)"
            (canplay)="onCanPlay()"
            *ngIf="showMedia"
        ></video>
        <div class="error-tip" *ngIf="showErrorTip">
            {{ errorTipText }}
        </div>
    `
                }]
        }], ctorParameters: function () { return [{ type: i1.DomSanitizer }]; }, propDecorators: { class: [{
                type: HostBinding,
                args: ['class']
            }], video: [{
                type: ViewChild,
                args: ['video']
            }], thySrc: [{
                type: Input
            }], thyAutoPlay: [{
                type: Input
            }] } });

class ThyProMediaModule {
}
ThyProMediaModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyProMediaModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ThyProMediaModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.2", ngImport: i0, type: ThyProMediaModule, declarations: [ThyMediaPlayerBaseComponent, ThyVideoPlayerComponent, ThyAudioPlayerComponent], imports: [CommonModule], exports: [ThyVideoPlayerComponent, ThyAudioPlayerComponent] });
ThyProMediaModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyProMediaModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.2", ngImport: i0, type: ThyProMediaModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ThyMediaPlayerBaseComponent, ThyVideoPlayerComponent, ThyAudioPlayerComponent],
                    imports: [CommonModule],
                    exports: [ThyVideoPlayerComponent, ThyAudioPlayerComponent],
                    providers: []
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ThyAudioPlayerComponent, ThyProMediaModule, ThyVideoPlayerComponent };
//# sourceMappingURL=tethys-pro-media.mjs.map
